@@ -84,6 +84,11 @@ def job_set_inv_payment(user, job, pricing):
             inv.balance = inv.total
             inv.estimate = 1
             inv.status_detail = 'estimate'
+            
+            if user and not user.is_anonymous():
+                inv.set_creator(user)
+                inv.set_owner(user)
+            
             inv.save(user)
 
             # tender the invoice
